/*
    Copyright (C) 2001-2002 KSVG Team
    This file is part of the KDE project

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/

#include "SVGRectElement.h"
#include "SVGRectElementImpl.h"
#include "SVGAnimatedLength.h"

using namespace KSVG;

SVGRectElement::SVGRectElement() : SVGElement(), SVGTests(), SVGLangSpace(), SVGExternalResourcesRequired(), SVGStylable(), SVGTransformable()
{
	impl = 0;
}

SVGRectElement::SVGRectElement(const SVGRectElement &other) : SVGElement(), SVGTests(), SVGLangSpace(), SVGExternalResourcesRequired(), SVGStylable(), SVGTransformable(), impl(0) 
{
	(*this) = other;
}

SVGRectElement &SVGRectElement::operator=(const SVGRectElement &other)
{
	if(impl == other.impl)
		return *this;

	if(impl)
		impl->deref();

	impl = other.impl;

	if(impl)
		impl->ref();

	return *this;
}

SVGRectElement::SVGRectElement(SVGRectElementImpl *other) : SVGElement(), SVGTests(), SVGLangSpace(), SVGExternalResourcesRequired(), SVGStylable(), SVGTransformable()
{
	impl = other;
	if(impl)
		impl->ref();
}

SVGRectElement::~SVGRectElement()
{
	if(impl)
		impl->deref();
}

SVGAnimatedLength SVGRectElement::x()
{
	if(!impl) return SVGAnimatedLength(0);
	return SVGAnimatedLength(impl->x());
}

SVGAnimatedLength SVGRectElement::y()
{
	if(!impl) return SVGAnimatedLength(0);
	return SVGAnimatedLength(impl->y());
}

SVGAnimatedLength SVGRectElement::width()
{
	if(!impl) return SVGAnimatedLength(0);
	return SVGAnimatedLength(impl->width());
}

SVGAnimatedLength SVGRectElement::height()
{
	if(!impl) return SVGAnimatedLength(0);
	return SVGAnimatedLength(impl->height());
}

SVGAnimatedLength SVGRectElement::rx()
{
	if(!impl) return SVGAnimatedLength(0);
	return SVGAnimatedLength(impl->rx());
}

SVGAnimatedLength SVGRectElement::ry()
{
	if(!impl) return SVGAnimatedLength(0);
	return SVGAnimatedLength(impl->ry());
}

// vim:ts=4:noet
